<?php
$TRANSLATIONS = array(
"Could not load template" => "A sablont nem sikerült betölteni",
"Saved" => "Elmentve!",
"Reset" => "Visszaállítás",
"An error occurred" => "Hiba történt",
"Sharing email - public link shares (HTML)" => "Megosztás - nyilvános hivatkozás megosztás (HTML)",
"Sharing email - public link shares (plain text fallback)" => "Megosztás - nyilvános hivatkozás megosztás (egyszerű szöveg)",
"Sharing email (HTML)" => "Megosztás (HTML)",
"Sharing email (plain text fallback)" => "Megosztás (egyszerű szöveg)",
"Lost password mail" => "Elfelejtett jelszó",
"New user email (HTML)" => "Új felhasználó (HTML)",
"New user email (plain text fallback)" => "Új felhasználó (egyszerű szöveg)",
"Activity notification mail" => "Aktivitás értesítő",
"Mail Templates" => "E-mail sablonok",
"Theme" => "Téma",
"Template" => "Sablon",
"Please choose a template" => "Kérjük válasszon egy sablont!",
"Save" => "Mentés"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
